
/**************************************************
/**************************************************
 *
 *   Contains the vocabulary and responses of
 *   Adventures on Planet Smir III, 1
 *
 **************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <conio.h>
#include <errno.h>
#include <ctype.h>

#include "aconst.h"
#include "words.h"
#include "rooms.h"
#include "player.h"

//#include a system's specific version of my SimpleIO library.
#ifdef __CBM__
#include "simpleio.h"
#elif defined __ATARI__
#include "atasimpleio.h"
#endif

//For 32k (large) cartridges, #include a header file containing function declarations that
//handle access to the extra memory.
#ifdef __DOFE3__
#include "c64cart_fe3\final3cart.H"
#endif

//If not compressing text, redirect calls to printtok() which prints compressed text to
//prints() from the *SImpleIO libraries which doesn't.
#ifdef __NOCOMPTEXT__
#define printtok prints
#else
//Otherwise, declare the function that prints compressed strings.
void __fastcall__ printtok (char* str);
#endif


/*************************************
	Items
 *************************************/

//Current item # in user input.
extern unsigned char Itm1;
#pragma zpsym ("Itm1")

//Current room #.
extern unsigned char CRoom;
#pragma zpsym ("CRoom")

//Temp. data.
extern unsigned char i, j, e;
#pragma zpsym ("i")
#pragma zpsym ("j")
#pragma zpsym ("e")

extern char* s;
#pragma zpsym ("s")

extern unsigned char CurPos;
#pragma zpsym ("CurPos")

extern unsigned char c;
#pragma zpsym ("c")

//Line of user input.
extern char Input [21];

//Temp. for searching for item name.
extern unsigned char CurItem;
#pragma zpsym ("CurItem")

//Commmonly-displayed messages.
const unsigned char* Message []=
{
/*  Message 0  */
	"Your inventory is full.",

/*  Message 1  */
	"You already have that."
};

#ifdef __VIC20__
#pragma code-name (push, "BUF4C")
#elif defined __PET__
#pragma code-name (push, "INPUTCODE")
#endif

#if defined __ATARI__ && !defined __DOCART__
#pragma code-name (push, "MBUFCODE")
#endif

//Prints message # m.
//#defines in words.h, and message texts are in the Messages array above..
void __fastcall__ printmsg(unsigned char m);

//Adds 15 to the score.
void addsc15 (void)
{Player.Score+=15;}

#ifdef __VIC20__
#pragma code-name ("BUF2C")
#endif

#ifdef __VIC20__
#pragma code-name (push, "BUF1C")
#elif defined __PET__
#pragma code-name (pop)
#elif defined __C16__ && !defined __DOCART__
#pragma code-name (push, "INPUTCO")
#endif

//Middleman for two commonly-displayed messages.
void printnoitem (void)
{printscr("That item is not available."); }

#ifdef __VIC20__
#pragma code-name ("BUF1C")
#endif

#if defined __C16__ && !defined __DOCART__
#pragma code-name (pop)
#endif

#if defined __PET__
#pragma code-name (push, "DOSCODE")
#endif
void printokay (void)
{printscr ("Okay.");}

#ifdef __VIC20__
#pragma code-name (pop)
#endif

//Pointer to current room info.
extern struct room* CRm;
#pragma zpsym ("CRm")

//Pointer to current room inventory.
extern unsigned char* CurRoomInv;
#pragma zpsym ("CurRoomInv");

#ifdef __VIC20__
#pragma code-name ("BUF3C")
#elif defined __PET__
#pragma code-name ("TAPECODE")
#endif

void __fastcall__ printperiod (void)
{printscr (".");}

#ifdef __VIC20__
#pragma code-name (pop)
#elif defined __PET__
#pragma code-name (pop)
#endif

#if defined __C16__ && !defined __DOCART__
#pragma code-name (push, "INPUTCO")
#endif

#ifdef __PET__
#pragma code-name (push, "TAPECODE")
#endif

#if defined __C64__ && !defined __DOCART__
//#pragma code-name (push, "TAPECODE")
#endif

//Prints the name of the item # given in Itm1.
void printitmname (void)
#ifdef __DOFE3__
//In a 32k cartridge, the item name is stored in the second 16k.
//printh() prints text stored there.
{printh (bankgetword((unsigned)(&Item[Itm1].Name))); printcr();}
#else
{printscr (Item[Itm1].Name);}
#endif

#if defined __C64__ && !defined __DOCART__
//#pragma code-name (pop)
#endif

//Compares two words.
//Used by FindItem().

#ifdef __VIC20__
#pragma code-name (push, "BUF3C")
#endif
#ifdef __PET__
#pragma code-name ("DOSCODE")
#endif
#if defined __C16__ && !defined __DOCART__
#pragma code-name ("TAPECO")
#endif

#if defined __ATARI__ && !defined __DOCART__
#pragma code-name (push, "MBUFCODE")
#endif

//This compares the noun given in user input after the verb to the noun specified
//by Dest.  Returns true if match or false otherwise.
static unsigned char __fastcall__ ScanWord (char* Dest)
{
//printscr (Dest);
#ifdef __DOFE3__
	//32k cartridges are stored in the second 16k and require
	//extra work.
	__asm__ (
		"\tjsr\tpopax\n"
		"\tsta\tptr4\n"
		"\tstx\tptr4+1\n"
		"\tldy\t#0\n"
		"@a01:\n"
		"\tlda\tptr4\n"
		"\tldx\tptr4+1\n"
		"\tjsr\t_bankgetbyte\n"
		"\tsta\t_c\n"
		"\tcmp\t(_s),y\n"
		"\tbne\t@a03\n"
		"\tlda\t_c\n"
		"\tbeq\t@a03\n"
		"\tiny\n"
		"\tbne\t@a01\n"
		"@a03:\n"
		"\tlda\t_c\n"
		"\tbne\t@a04\n"
		"\tjmp\treturn1\n"
		"@a04:\n"
		"\tjmp\treturn0\n"
		);
#else
	__asm__ (
		"\tjsr\tpopax\n"
		"\tsta\tptr4\n"
		"\tstx\tptr4+1\n"
		"\tldy\t#0\n"
		"@a01:\n"
		"\tlda\t(ptr4),y\n"
		"\tsta\t_c\n"
// "\tpha\n"
// "\tjsr\t$ffd2\n\n"
// "\tpla\n"
		"\tcmp\t(_s),y\n"
		"\tbne\t@a03\n"
		"\tlda\t_c\n"
		"\tbeq\t@a03\n"
		"\tiny\n"
		"\tbne\t@a01\n"
		"@a03:\n"
		"\tlda\t_c\n"
		"\tbne\t@a04\n"
		"\tjmp\treturn1\n"
		"@a04:\n"
		"\tjmp\treturn0\n"
		);
#endif
}


#ifdef __VIC20__
#pragma code-name (pop)
#endif

#ifdef __PET__
#pragma code-name (pop)
#endif

//Searches the verbs for the beginning of Input[] and returns the entry #.
//If not found, returns 0xFF.
unsigned char FindVerb (void)
{
	//Main verb-scan loop.
	for (j=0; j<NumVerbs; ++j)
	{
		//Start at the begining of the verb entry and user input.
		CurPos=0;
		//Scan the current verb until either the end of both strings 
		//or a mismatch.
#ifdef __DOFE3__
		//On 32k cartridges, the verb names are also in the second 16k.
		for (;
			(c=bankgetbyte((char*)bankgetword((void*)&Verb[j].Name)+CurPos)) &&
			(e=Input[CurPos])==c &&
			e >= 33
				;)
				{++CurPos;}
#else
		for (;
			(e=Input[CurPos])==(c=Verb[j].Name[CurPos]) &&
			e >= 33 && c
				;)
				{++CurPos;}
#endif
		//If end of the verb and either end on input or a prace,
		//return current cerb #.
		if (e<33 && c==0)
		{
			//CurPos=CurPos;
			return j;
		}
	}
	//Skip to the end of the verb in user input and write a NUL
	//so the main loop can print just the verb that's not found.
	__asm__ (
		"\tldx\t_CurPos\n"
		"a00:\n"
		"\tlda\t_Input,x\n"
		"\tcmp\t#33\n"
		"\tbcc\ta01\n"
		"\tinx\n"
		"\tbne\ta00\n"
		"a01:\n"
		//"\tstx\t_CurPos\n"
		"\tlda\t#0\n"
		"\tsta\t_Input,x\n"
		);
	return -1;
}

#if defined __C64__ && !defined __DOCART__
#pragma code-name (push, "RS232CODE")
#endif

#if defined __ATARI__ && !defined __DOCART__
#pragma code-name (pop)
#endif

#if defined __C16__ && !defined __DOCART__
#pragma code-name (pop)
#endif

//Searches for user-inputted item #.
//Returns 0xFF if not found.
unsigned char __fastcall__ FindItem (void)
{
	/*  Search for item in Input */
	for (CurItem=0; CurItem < NumItems; ++CurItem)
	{
#ifdef __DOFE3__
		if (ScanWord(bankgetword((ItemPtr=&Item[CurItem])->Name))) {
			//ItemPtr=&Item[CurItem];
			return CurItem;
			
#else
		if (ScanWord((ItemPtr=&Item[CurItem])->Name)) {
			return CurItem;
#endif
		}
	}
	for (CurItem = 0; CurItem < 4; ++CurItem)
	{
		if (ScanWord((char*)&RoomDir[CurItem])) {
			return CurItem | 160;
		}
	}
	return -1;
}

#if defined __C64__ && !defined __DOCART__
#pragma code-name (pop)
#endif

//Adds Itm1 to given inventory.
//returns 0 if successful or 1 if full.
unsigned char __fastcall__ AddInv (unsigned char* Inv)
{
	__asm__ (
		//Get address of Inv where the item indicated by Itm1
		//is to be added.
		"\tjsr\tpopax\n"
		"\tsta\tptr1\n"
		"\tstx\tptr1+1\n"
		//Search for either end of Inv or a match of Itm1.
		"\tldy\t#0\n"
		"@a01:\n"
		"\tlda\t(ptr1),y\n"
		//"\tcmp\t#$FF\n"
		//Continue to add if empty item found (entry=-1).
		"\tbmi\t@a02\n"
		"\tiny\n"
		//Loop search until end of inventory (8 bytes per inventory)
		"\tcpy\t#8\n"
		//If so, return 1 for inventory full.
		"\tbcc\t@a01\n"
		"\tjmp\treturn1\n"
		"@a02:\n"
		//Put item # in next byte in inventory.
		"\tlda\t_Itm1\n"
		"\tsta\t(ptr1),y\n"
		//Advance and write item in next entry.
		"\tiny\n"
		"\tcpy\t#8\n"
		"\tbcs\t@a03\n"
		"\tlda\t#$FF\n"
		"\tsta\t(ptr1),y\n"
		"@a03:\n"
		"\tjmp\treturn0\n"
		);
};

#if defined __ATARI__ && !defined __DOCART__
//#pragma code-name (pop)
#endif


#ifdef __VIC20__
#pragma code-name (push, "BUF3C")
#endif
#ifdef __PET__
#pragma code-name (push, "INPUTCODE")
#endif
#if defined __C64__ && !defined __DOCART__
#pragma code-name (push, "TAPECODE")
#endif



//Middleman for adding to player's inventory.
unsigned char AddInvPlayer (void)
{return AddInv (Player.Inv);}

#ifdef __VIC20__
#pragma code-name (pop)
#endif

#ifdef __PET__
#pragma code-name ("DOSCODE")
#endif


#if defined __C16__ && !defined __DOCART__
#pragma code-name (push, "BSTKCO")
#endif


//Removes an item in Itm1 from given inventory.
//Returns 1 if found and 0 otherwise.
unsigned char __fastcall__ RemoveInv (unsigned char* Inv)
{
	__asm__ (
		"\tjsr\tpopax\n"
		"\tsta\tptr1\n"
		"\tstx\tptr1+1\n"
		"\tldy\t#0\n"
		"@a01:\n"
		"\tlda\t(ptr1),y\n"
		"\tbmi\t@a09\n"
		"\tcmp\t_Itm1\n"
		"\tbeq\t@a02\n"
		"\tiny\n"
		"\tcpy\t#8\n"
		"\tbcc\t@a01\n"
		"@a09:\n"
		"\tjmp\treturn0\n"
		"@a02:\n"
		"\tiny\n"
		"\tlda\t(ptr1),y\n"
		"\tdey\n"
		"\tsta\t(ptr1),y\n"
		"\tiny\n"
		"\tcpy\t#8\n"
		"\tbcc\t@a02\n"
		"\tlda\t#$FF\n"
		"\tldy\t#7\n"
		"\tsta\t\t(ptr1),y\n"
		"\tjmp\treturn1\n"
		);
};

#if defined __ATARI__ && !defined __DOCART__
//#pragma code-name (pop)
#endif


#ifdef __VIC20__
#pragma code-name (push, "BUF3C")
#elif defined __C16__ && !defined __DOCART__
#pragma code-name (push, "INPUTCO")
#endif
#ifdef __PET__
#pragma code-name ("INPUTCODE")
#endif

#if defined __ATARI__ && !defined __DOCART__
#pragma code-name (push, "MBUFCODE")
#endif

#if defined __C64__ && !defined __DOCART__
#pragma code-name (push, "TAPECODE")
#endif


/* Searches inventory at Inv for item # in Itm1.
 * Returns 1 for found and 0 for not found.
 */
unsigned char __fastcall__ SearchInv2 (unsigned char* Inv)
{
	__asm__ (
		//Get inventory pointer from stack.
		"\tjsr\tpopax\n"
		"\tsta\tptr1\n"
		"\tstx\tptr1+1\n"
		//Start loop for scanning given inventory for item.
		"\tldy\t#0\n"
		"@a01:\n"
		//Get current item from inventory.
		"\tlda\t(ptr1),y\n"
		//Empty item? (Neg. means yes.)  Exit not found.
		"\tbmi\t@a09\n"
		//Match found?  Exit found.
		"\tcmp\t_Itm1\n"
		"\tbeq\t@a08\n"
		//Loop until eight bytes read--limit of inventory size.
		"\tiny\n"
		"\tcpy\t#8\n"
		"\tbcc\t@a01\n"
		//Return conditions.
		"@a09:\n"
		"\tjmp\treturn0\n"
		"@a08:\n"
		"\tjmp\treturn1\n"
		);
}

#ifdef __VIC20__
#pragma code-name ("BUF4C")
#endif
#ifdef __PET__
#pragma code-name ("DOSCODE")
#endif

#if defined __C64__ && !defined __DOCART__
#pragma code-name ("RS232CODE")
#endif

//Middleman to search player's inventory for Itm1.
unsigned char SearchInvPlayer (void)
{
	return SearchInv2 (&Player.Inv);
}

//Middleman to search current room's inventory for Itm1.
unsigned char SearchInvRoom (void)
{return SearchInv2 (CurRoomInv);}

#ifdef __VIC20__
#pragma code-name (pop)
#endif

#ifdef __PET__
#pragma code-name (pop)
#endif

#if defined __C16__ && !defined __DOCART__
#pragma code-name (pop)
#endif

#if defined __C16__ && !defined __DOCART__
#pragma code-name (push, "TAPECO")
#elif defined __PET__
#pragma code-name (push, "DOSCODE")
#endif

#if defined __C64__ && !defined __DOCART__
#pragma code-name (pop)
#endif

//Display player's score if "score" typed.
void vScore (void)
{
	prints ("Your score is ");
	printu (Player.Score);
	printperiod ();
}

#if !defined __C64__  && !defined __VIC20__ && !defined __DOCART__
//#pragma code-name (pop)
#endif

#if defined __C64__ && !defined __DOCART__
#pragma code-name (pop)
#endif

static const char roomexitletters [4]="NSEW";
//Describes room if Itm1 if 0xFF (empty) or the given item otherwise.
void vLook (void)
{
	//static char* s2;
	//If an item is specified:
	if ((signed char)Itm1>=0) {
		//If it is available in the player inventory
		//or in the current room,
		if (SearchInvPlayer () || SearchInvRoom ())
		{
			//get string address and print help text.
			//You can delete the condition and substitute s
			//in the folloewing printscr() function with the
			//asignment in the condition.
#ifdef __DOFE3__
			if ((s=bankgetword((void*)&ItemPtr->Info))==0) {
#else
			if ((s=((void*)ItemPtr->Info))==0) {
#endif
				//Error if no help available.
				printscr ("No help available for that item.");
				return;
			}
			//Print item description then Return.
			//The return is printed here so the item's describe doesn't
			//need to end with a Return.
			printtok (s); 
			printcr ();
		} else {
			printnoitem ();
		}
		return;
	}
	//Otherwise,
	//get room inventory pointer,
	CurRoomInv=Player.RoomInv[CRoom];
	//room entry pointer,
	CRm=(void*)&Room[CRoom];
	//print room description,
#ifdef __DOFE3__'
	//(In second 16k of 32k cartridge)
	//printtok (bankgetword(&CRm->Desc));
	__asm__ (
		"\tldy\t#1\n"
		"\tlda\t(_CRm),y\n"
		"\ttax\n"
		"\tdey\n"
		"\tlda\t(_CRm),y\n"
		"\tjsr\t_bankgetword\n"
#ifdef __NOCOMPTEXT__
		"\tjsr\t_printh\n"
#else
		"\tjsr\t_printtok\n"
#endif
		);
#else
	//(or use assembler for size optimization otherwise)
	__asm__ (
		"\tldy\t#1\n"
		"\tlda\t(_CRm),y\n"
		"\ttax\n"
		"\tdey\n"
		"\tlda\t(_CRm),y\n"
#ifdef __NOCOMPTEXT__
		"\tjsr\t_prints\n"
#else
		"\tjsr\t_printtok\n"
#endif
		);
#endif
	//and print available exits.
	prints ("Exits: ");
#ifdef __DOFE3__
	for (i=0; i<4; ++i) if (bankgetbyte(&CRm->NextRoom[i])!=0xFF) printc (roomexitletters[i]);
#else
	//On Atari systems, the ROM's char output routine changes the .Y register, so
	//that register needs to be preserved.
#ifdef __ATARI__
	__asm__ (
		//The room's exit starts at pos. 2 of the room's entry address.
		"\tldy\t#2\n"
		"\tsty\ttmp4\n"
		"@a01:\n"
		//Get current room exit's destination.
		"\tlda\t(_CRm),y\n"
		//If -, skip write.
		"\tbmi\t@a02\n"
		//Print the exit type's character.
		//Since the room's exits offset starts at 2,
		//subtract 2 from the exit character array's address instead of .Y
		//to skip two dety's.
		"\tlda\t_roomexitletters-2,y\n"
		"\tjsr\t_printc\n"
		"@a02:\n"
		//Increase offset in room until 6, end of exits.
		"\tinc\ttmp4\n"
		"\tldy\ttmp4\n"
		"\tcpy\t#6\n"
		"\tbcc\t@a01\n"
		);
#else
	//Same as the Atari8 version, but the offset can stay in .Y.
	__asm__ (
		"\tldy\t#2\n"
		"a01:\n"
		"\tlda\t(_CRm),y\n"
		"\tbmi\ta02\n"
		"\tlda\t_roomexitletters-2,y\n"
		"\tjsr\t_printc\n"
		"a02:\n"
		"\tiny\n"
		"\tcpy\t#6\n"
		"\tbcc\ta01\n"
		);
#endif
#endif
	printcr ();
	//and list room items if any (first entry is not -1).
	if (CurRoomInv[0]!=0xFF) {
		printscr ("Items:");
		for (i=0; i<8 && (signed char)(Itm1=CurRoomInv[i])>=0;++i) {
			prints ("    ");
			printitmname ();
		}
	}
}

#if defined __ATARI__ && !defined __DOCART__
#pragma code-name ("MBUFCODE")
#endif

#ifdef __VIC20__
#pragma code-name (push, "BUF1C")
#elif defined __C16__ && !defined __DOCART__
#pragma code-name (push, "TAPECO")
#endif

#if defined __ATARI__ && !defined __DOCART__
#pragma code-name (push, "MBUFCODE")
#endif

#ifdef __PET__
#pragma code-name (push, "TAPECODE")
#endif

#if defined __C16__ && !defined __DOCART__
#pragma code-name (push, "INPUTCO")
#endif

#if defined __C64__ && !defined __DOCART__
#pragma code-name (push, "TAPECODE")
#endif

//Middleman for vLook and no item specified.
void vLook2 (void)
{
	Itm1=-1;
	vLook ();

}

#if defined __C16__ && !defined __DOCART__
#pragma code-name (pop)
#endif

#ifdef __VIC20__
#pragma code-name ("BUF2C")
#endif

#ifdef __PET__
#pragma code-name (pop)
#endif

#if defined __C16__ && !defined __DOCART__
#pragma code-name (push, "INPUTCO")
#endif

#if defined __ATARI__ && !defined __DOCART__
#pragma code-name (push, "MBUFCODE")
#endif

#if defined __C64__ && !defined __DOCART__
#pragma code-name (pop)
#endif

#if defined __C64__ && !defined __DOCART__
#pragma code-name (push, "ZP2CODE")
#endif

//Change to a different room.
void vGo (void)
{
	//Itm1-=160;
	//Check if Itm1 is a valid direction (between 160 and 163).
	//Error if not.
		//Convert to offset in room's exits.
		//j = Itm1&0x0F; 
		//Read room exit's destination and error if not valid.
#ifdef __DOFE3__
	if ((Itm1-=160)<4 && (i=bankgetbyte(&CRm->NextRoom[Itm1]))!=0xFF) {
#else
	if ((Itm1-=160)<4 && (signed char)(i=CRm->NextRoom[Itm1])>=0) {
#endif
			//goto err;
			//}
			//Set currenr room and describe the new room.
			//vLook(), which is called by vLook2() with no item,
			//finishes the update.
			CRoom = i;
			vLook2 (); return;
		}
	//}
	//Print error message.
err:	printscr("You can't go that way.");
}

#if defined __C64__ && !defined __DOCART__
#pragma code-name (pop)
#endif

#if !defined __PET__ && !defined __C64__ && !defined __DOCART__
#pragma code-name (pop)
#endif

#ifdef __VIC20__
#pragma code-name (push, "BUF3C")
#elif defined __C16__
#if defined __C16__ && !defined __DOCART__
#pragma code-name ("TAPECO")
#endif
#elif defined __PET__
#pragma code-name (push, "TAPECODE")
#endif

#if defined __ATARI__ && !defined __DOCART__
#pragma code-name (push, "MBUFCODE")
#endif

#if defined __C64__ && !defined __DOCART__
#pragma code-name (push, "ZP2CODE")
#endif


//Middlemen for quick going (i.e. N S E W).
void vGoNorth	(void)
{
	Itm1=iNorth; vGo();
}

void vGoSouth	(void)
{
	Itm1=iSouth; vGo();
}

void vGoEast	(void)
{
	Itm1=iEast; vGo();
}

void vGoWest	(void)
{
	Itm1=iWest; vGo();
}

#if defined __C64__ && !defined __DOCART__
#pragma code-name (pop)
#endif

#if defined __ATARI__ && !defined __DOCART__
#pragma code-name (pop)
#endif

#if !defined __PET__ && !defined __C64__ && !defined __DOCART__
#pragma code-name (pop)
#endif

#if defined __C16__ && !defined __DOCART__
#pragma code-name (push, "INPUTCO")
#endif

#if defined __ATARI__ && !defined __DOCART__
#pragma code-name (push, "MBUFCODE")
#endif

#if defined __C64__ && !defined __DOCART__
#pragma code-name (push, "TAPECODE")
#endif

//Pick up an item.
void vGet (void)
{
	//Error if player inventory is full.
	if ((signed char)Player.Inv[7]>=0) {
		printmsg (msgHoldingTooManyItems);
		return;
	}
	//Remove item from room and error if not found.
	if (!RemoveInv (CurRoomInv)) {
		printnoitem ();
		return;
	}
	//Add to player inventory and error if full.
	AddInvPlayer ();
	printokay ();
	return;
}

#if defined __C16__ && !defined __DOCART__
#pragma code-name ("INPUTCO")
#endif
#ifdef __PET__
#pragma code-name (pop)
#endif

void vPut (void)
{
	if (!RemoveInv (Player.Inv)) {
		printscr ("You don't have that."); return;
	}
	if (AddInv (CurRoomInv))
	{
		printscr ("This room is full.");
		return;
	}
	printokay ();
}

#if defined __C64__ && !defined __DOCART__
#pragma code-name (pop)
#endif

#if defined __C16__ && !defined __DOCART__
#pragma code-name ("BSTKCO")
#endif

//Displays the player's inventory.
void vItems (void)
{
	printscr ("You have:");
	//Scan the inventory until no tem (-1).
	//Get the current item at the current pos.,
	for (i=0; i<8 && (signed char)(Itm1=Player.Inv[i])>=0; ) {
		//emulate a tab,
		prints ("    ");
		//and print the item name.
		//This routine prints the name of the item specified by Itm1 then a Return.
		printitmname ();
		//Advance.
		++i;
	}
	//If currenr pos. is 0, which would happen ifr the first bytw indicates empty
	//print "Nothing."
	if (!i) printscr ("Nothing.");
}

#if defined __ATARI__ && !defined __DOCART__
#pragma code-name (pop)
#endif

#if defined __C16__ && !defined __DOCART__
#pragma code-name (pop)
#endif

//Provides help for current condition.
void vHelp (void) {
	switch (CRoom) {
	}
nohelp:
	printscr ("No help currently available.");
}

//Two help pages to be displayed when the user types in "intro."
//Defined in WordsDB.c.
//Fill the array defined in the "WordsDB.c" file with the intro messages to be
//displayed when the player types "intro."
//If you need more, increase the subscript value here and in the
//"WordsDB.c" file, add mre pages to the definition and add code to display
//the extra pages to vIntro().
extern const char* HelpPages[2];

#if defined __C16__ && !defined __DOCART__
#pragma code-name (push, "ZP2CO")
#endif

#ifdef __VIC20__
#pragma code-name (push, "BUF2C")
#endif
#if defined __ATARI__ && !defined __DOCART__
#pragma code-name (push, "MBUFCODE")
#endif


//Code for the verd "intro."
//Display each page of the intro text and pause for the user to
//continue.  If not the last page, the user can type 'x' to exit function.
//Return immediately if last page.
void vIntro (void)
{
	//32k cartridges need extra work, as both the intro text
	//and the pointers to such are stored in the second 16k.
#ifdef __DOFE3__
	//You can copy the next three lines asc many times as needed,
	//incrementing the subscript value for each page.
	clrscr();				//This is needed because a screen
						//clear may be interpreted as a token by
						//the printtok() function.
	printtok (bankgetword((void*)&HelpPages[0]));
	if ((getkey())=='x') return;
	clrscr();
	printtok (bankgetword((void*)&HelpPages[1]));
#else
	//You can copy the next three lines asc many times as needed,
	//incrementing the subscript value for each page.
	clrscr();				//This is needed because a screen
						//clear may be interpreted as a token by
						//the printtok() function.
	printtok (((void*)HelpPages[0]));
	if ((getkey())=='x') return;
	clrscr();
	printtok (((void*)HelpPages[1]));
#endif
}

#if !defined __PET__ && !defined __C64__ && !defined __DOCART__
#pragma code-name (pop)
#endif


//Code for the verd "read."
void vRead (void)
{
	//Check if the item is available.
	if (SearchInvPlayer() && SearchInvRoom()) {
		printnoitem ();
		return;
	}
	//Print text for readable items.
	//Use return; after each item.
	switch (Itm1)
	{
	}
	//Error if the item can't be "read."
	printscr ("Can't read this.");
}

