#ifndef __adv_words_H
#define __adv_words_H

#include "aconst.h"
/****************************************************
 *
 *	 Defines structs to hold verbs, nouns and
 *	 special data related to some objects.
 *
 ****************************************************/

//Declaration for the value of the current item.
extern unsigned char Itm1;
#pragma zpsym ("Itm1")

//Declaration of entry to hold a verb and its definition.
typedef struct verb_
{
	//Verb name.
	unsigned char* Name;
	//Pointer to verb-handling routine.
	//You can specify the same routine twice, useful for synonyms.
	void (*vdo) (void);
};

//Declares the verb database.
//If you need more verbs, increase the definition of "NumVerbs"
//in the "aconst.h" file to the number of verbs available.
extern struct verb_ Verb [NumVerbs];

//Routine to find the user input's verb in the verb database and
//return verb # or -1 if not found.
unsigned char FindVerb (void);

//Declaration of entry to hold an item's name
//and its associated help, displayed when a user types
//"look <verb>."
typedef struct item_
{
	//Name`.
	unsigned char* Name;
	//Help text.
	unsigned char *Info;
};

//Declare item list and a pointer to the current user input's
//noun.
extern struct item_ Item [NumItems], *ItemPtr;
#pragma zpsym ("ItemPtr")

unsigned char __fastcall__ FindItem (void);


/****************************************************
   Item Numbers
 ****************************************************/

//Enum to hold each item's variable name and its associated #.
//Somebody online said that #defines are more efficient than
//enum.

//It is recommended that you start the name with "i" and add the item with the
//first capital.
#define iKey		  0

//Room exit variable names and their associated item #'s
#define iNorth		160
#define iSouth		161
#define iEast		162
#define iWest		163

/* People srart at 192 */

/****************************************************
   General verb-handlers
 ****************************************************/

void vLook	(void);
void vGo	(void);
void vItems	(void); /* Inventory */

void vGet	(void);
void vPut	(void);
void vRead	(void);


void vIntro	(void);
void vHelp	(void);

void vScore	(void);

void vGoNorth	(void);
void vGoSouth	(void);
void vGoEast	(void);
void vGoWest	(void);

/****************************************************
   Message Numbers
 ****************************************************/
 //Array that stores messages displayed often in the game.
extern const unsigned char* Message [];

//Enum to hold the variable names of said messages.
#define msgHoldingTooManyItems		0
#define msgAlreadyHave			1

#endif

